@@ -18,14 +18,19 @@ open_raw_sock(prot)
 
     if ((fd = socket(AF_INET, SOCK_RAW, prot)) < 0)
     {
-        perror("open_raw_socket: SOCK_RAW allocation error");
+        fprintf(stderr,
+                "open_raw_socket: error: SOCK_RAW allocation: %s",
+                strerror(errno));
         return (-1);
     }
     if (setsockopt(fd, IPPROTO_IP, IP_HDRINCL, &one, sizeof(one)) < 0)
     {
-        perror("open_raw_socket: Cannot set IP_HDRINCL socket option");
+        fprintf(stderr,
+                "open_raw_socket: error: setting IP_HDRINCL: %s",
+                strerror(errno));
         return (-1);
     }
+    DEBUG("Successfully opened a type %d socket and set IP_HDRINCL\n", prot);
     return (fd);
 }
 
